Stan Math Library: stan/math/prim/scal/prob/beta_rng.hpp Source File

| Stan Math Library 2.10.0 reverse mode automatic differentiation

- Main Page
- Modules
- Namespaces
- Classes
- Files

- File List
- File Members

beta_rng.hpp
Go to the documentation of this file.
1 #ifndef STAN_MATH_PRIM_SCAL_PROB_BETA_RNG_HPP
2 #define STAN_MATH_PRIM_SCAL_PROB_BETA_RNG_HPP
3
4 #include <boost/math/special_functions/gamma.hpp>
5 #include <boost/random/gamma_distribution.hpp>
6 #include <boost/random/variate_generator.hpp>
7 #include <stan/math/prim/scal/err/check_consistent_sizes.hpp>
8 #include <stan/math/prim/scal/err/check_less_or_equal.hpp>
9 #include <stan/math/prim/scal/err/check_nonnegative.hpp>
10 #include <stan/math/prim/scal/err/check_not_nan.hpp>
11 #include <stan/math/prim/scal/err/check_positive_finite.hpp>
12 #include <stan/math/prim/scal/fun/log1m.hpp>
13 #include <stan/math/prim/scal/fun/multiply_log.hpp>
14 #include <stan/math/prim/scal/fun/value_of.hpp>
15 #include <stan/math/prim/scal/fun/digamma.hpp>
16 #include <stan/math/prim/scal/fun/lgamma.hpp>
17 #include <stan/math/prim/scal/fun/lbeta.hpp>
18 #include <stan/math/prim/scal/fun/constants.hpp>
19 #include <stan/math/prim/scal/meta/include_summand.hpp>
20 #include <stan/math/prim/scal/fun/grad_reg_inc_beta.hpp>
21 #include <stan/math/prim/scal/fun/inc_beta.hpp>
22
23 namespace stan {
24
25 namespace math {
26
27 template <class RNG>
28 inline double
29 beta_rng(const double alpha,
30 const double beta,
31 RNG& rng) {
32 using boost::variate_generator;
33 using boost::random::gamma_distribution;
34 // Error checks
35 static const char* function("stan::math::beta_rng");
36
37 using stan::math::check_positive_finite;
38
39 check_positive_finite(function, "First shape parameter", alpha);
40 check_positive_finite(function, "Second shape parameter", beta);
41
42 variate_generator<RNG&, gamma_distribution<> >
43 rng_gamma_alpha(rng, gamma_distribution<>(alpha, 1.0));
44 variate_generator<RNG&, gamma_distribution<> >
45 rng_gamma_beta(rng, gamma_distribution<>(beta, 1.0));
46 double a = rng_gamma_alpha();
47 double b = rng_gamma_beta();
48 return a / (a + b);
49 }
50
51 }
52 }
53 #endif
check_not_nan.hpp
lgamma.hpp
stan::math::beta_rng
double beta_rng(const double alpha, const double beta, RNG &rng)
Definition: beta_rng.hpp:29
check_positive_finite.hpp
stan
Definition: log_sum_exp.hpp:8
digamma.hpp
include_summand.hpp
multiply_log.hpp
check_nonnegative.hpp
check_less_or_equal.hpp
log1m.hpp
grad_reg_inc_beta.hpp
constants.hpp
lbeta.hpp
inc_beta.hpp
value_of.hpp
check_consistent_sizes.hpp
stan::math::check_positive_finite
bool check_positive_finite(const char *function, const char *name, const T_y &y)
Return true if y is positive and finite.
Definition: check_positive_finite.hpp:28

[ Stan Home Page ] © 2011–2016, Stan Development Team.